@@ -3,8 +3,5 @@ from .Friends import Friends
 from .Games import Games
 from .Inventory import Inventory
 from .Users import Users
-<<<<<<< HEAD
 from .Errors import Errors
-=======
-from .Groups import Groups
->>>>>>> 78dc8966b1fb5ddcb39cc10e1ab694ce1091aed0
+from .Groups import Groups
\ No newline at end of file
